<?php

class GetQuotation {
    private $tokenUrl;
    private $credentials;
    private $dataUrl;
    private $token;

    public function __construct($tokenUrl, $credentials, $dataUrl) {
        $this->tokenUrl = $tokenUrl;
        $this->credentials = $credentials;
        $this->dataUrl = $dataUrl;
    }

    // Function to get the Bearer Token
    public function getBearerToken() {
        $ch = curl_init($this->tokenUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query($this->credentials));
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            'Content-Type: application/x-www-form-urlencoded'
        ]);

        $response = curl_exec($ch);
        curl_close($ch);

        $data = json_decode($response, true);
        if (isset($data['token'])) {
            $this->token = $data['token'];
        } else {
            throw new Exception("Unable to get token. Response: " . $response);
        }
    }

    // Function to fetch data using the Bearer Token
    public function fetchData() {
        if (!$this->token) {
            throw new Exception("Token is not set. Please call getBearerToken() first.");
        }

        $ch = curl_init($this->dataUrl);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            "Authorization: Bearer $this->token"
        ]);

        $response = curl_exec($ch);
        curl_close($ch);

        return json_decode($response, true);
    }

    // Function to get the data with error handling
    public function getData() {
        try {
            $this->getBearerToken();
            return $this->fetchData();
        } catch (Exception $e) {
            return ['error' => $e->getMessage()];
        }
    }
}

?>
